@@ -3,6 +3,8 @@
 #' @export
 #'
 #' @param text (character) The source text
+#' @param key (character) API key. required either passed in here or save
+#' as an env var or R option. see \code{\link{rif}} and \code{\link{Startup}}
 #' @param ... Curl options passed on to [crul::HttpClient()]
 #' @family lexical
 #'
@@ -19,9 +21,9 @@
 #' lexical_chunks(gsub("\n", "", text))
 #' }
 
-lexical_chunks <- function(text, ...) {
+lexical_chunks <- function(text, key = NULL, ...) {
   start_end(nif_parse(
-    nif_GET("lexical/chunks", list(text = text), ...),
+    nif_GET("lexical/chunks.json", list(text = text, key = key_check(key)), ...),
     TRUE
   ))
 }
