@@ -1,6 +1,8 @@
 #' Search literature retractions
 #'
 #' @export
+#' @param key (character) API key. required either passed in here or save
+#' as an env var or R option. see \code{\link{rif}} and \code{\link{Startup}}
 #' @param ... Curl options passed on to [crul::HttpClient()]
 #' @family literature
 #' @examples \dontrun{
@@ -10,8 +12,8 @@
 #' literature_pmid(pmid = out[1])
 #' }
 
-literature_retractions <- function(...) {
+literature_retractions <- function(key = NULL, ...) {
   nif_parse(
-    nif_GET("literature/retractions", NULL, ...), TRUE
+    nif_GET("literature/retractions.json", list(key = key_check(key)), ...), TRUE
   )[[1]]
 }
