@@ -23,11 +23,11 @@
 #' }
 
 rif_summary <- function(query, expandSynonyms=TRUE, expandAcronyms=FALSE,
-  expandAbbrevs=FALSE, expandInferred=TRUE, ...){
+  expandAbbrevs=FALSE, expandInferred=TRUE, key = NULL, ...) {
 
   args <- nc(list(q = query, expandSynonyms = al(expandSynonyms),
                   expandAcronyms = al(expandAcronyms),
                   expandAbbrevs = al(expandAbbrevs),
-                  expandInferred = al(expandInferred)))
+                  expandInferred = al(expandInferred), key = key_check(key)))
   nif_parse(nif_GET("summary.json", args, ...), TRUE)
 }
