@@ -7,6 +7,8 @@
 #' @param limit The number of candidates to return. Default: 20
 #' @param category A category
 #' @param vocabulary A vocabulary
+#' @param key (character) API key. required either passed in here or save
+#' as an env var or R option. see \code{\link{rif}} and \code{\link{Startup}}
 #' @param ... Curl options passed on to [crul::HttpClient()]
 #' @family vocabulary
 #'
@@ -18,17 +20,17 @@
 #' }
 
 vocabulary <- function(prefix = NULL, id = NULL, limit = 20,
-                       category = NULL, vocabulary = NULL, ...) {
+                       category = NULL, vocabulary = NULL, key = NULL, ...) {
 
   if (!xor(is.null(prefix), is.null(id))) {
     stop("Provide only one of prefix or id", call. = FALSE)
   }
   args <- nc(list(prefix = prefix, limit = limit, category = category,
-                  vocabulary = vocabulary))
+                  vocabulary = vocabulary, key = key_check(key)))
   route <- if (is.null(id)) {
-    "vocabulary"
+    "vocabulary.json"
   } else {
-    file.path("vocabulary", id)
+    file.path("vocabulary", paste0(id, ".json"))
   }
   tibble::as_tibble(nif_parse(nif_GET(route, args, ...), TRUE))
 }
