@@ -1,9 +1,10 @@
 context("literature_retractions")
 
 test_that("literature_retractions", {
+	skip_on_cran()
+
   tt <- literature_retractions()
 
   expect_is(tt, "character")
-  expect_equal(length(tt), 4653)
-  expect_match(tt[1], "21386829")
+  expect_gt(length(tt), 4000)
 })
